@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2014  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -33,7 +33,6 @@ except ImportError:
 import stat
 import lxml.etree
 import logging
-import random
 import guestfs
 import socket
 import struct
@@ -59,12 +58,19 @@ class Guest(object):
         if self.libvirt_type is None:
             doc = lxml.etree.fromstring(self.libvirt_conn.getCapabilities())
 
-            if len(doc.xpath("/capabilities/guest/arch[@name='%s']/domain[@type='kvm']" % (self.tdl.arch))) > 0:
+            # Libvirt calls the old intel 32-bit architecture i686, while we
+            # refer to it as i686.  Do the mapping here, since we need to look
+            # up the libvirt name.
+            libvirtarch = self.tdl.arch
+            if libvirtarch == 'i386':
+                libvirtarch = 'i686'
+
+            if len(doc.xpath("/capabilities/guest/arch[@name='%s']/domain[@type='kvm']" % (libvirtarch))) > 0:
                 self.libvirt_type = 'kvm'
-            elif len(doc.xpath("/capabilities/guest/arch[@name='%s']/domain[@type='qemu']" % (self.tdl.arch))) > 0:
+            elif len(doc.xpath("/capabilities/guest/arch[@name='%s']/domain[@type='qemu']" % (libvirtarch))) > 0:
                 self.libvirt_type = 'qemu'
             else:
-                raise oz.OzException.OzException("This host does not support virtualization type kvm or qemu for TDL arch (%s)" % (self.tdl.arch))
+                raise oz.OzException.OzException("This host does not support virtualization type kvm or qemu for TDL arch (%s)" % (libvirtarch))
 
         self.log.debug("Libvirt type is %s", self.libvirt_type)
 
@@ -219,7 +225,13 @@ class Guest(object):
 
         self.icicle_tmp = os.path.join(self.data_dir, "icicletmp",
                                        self.tdl.name)
-        self.listen_port = random.randrange(1024, 65535)
+
+        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        # Bind to port 0 which will use a free socket to listen to.
+        sock.bind(("", 0))
+        self.listen_port = sock.getsockname()[1]
+        # Close the socket to free it up for libvirt
+        sock.close()
 
         self.connect_to_libvirt()
 
@@ -1437,6 +1449,9 @@ class CDGuest(Guest):
                                        self.tdl.name + "-" + self.tdl.installtype + "-oz.iso")
         self.iso_contents = os.path.join(self.data_dir, "isocontent",
                                          self.tdl.name + "-" + self.tdl.installtype)
+        # An optional floppy disk to be used for installation
+        self.output_floppy = os.path.join(self.output_dir,
+                                          self.tdl.name + "-" + self.tdl.installtype + "-oz.img")
 
         self.log.debug("Original ISO path: %s", self.orig_iso)
         self.log.debug("Modified ISO cache: %s", self.modified_iso_cache)
@@ -1862,6 +1877,11 @@ class CDGuest(Guest):
         except:
             pass
 
+        try:
+            os.unlink(self.output_floppy)
+        except:
+            pass
+
         if not self.cache_original_media:
             try:
                 os.unlink(self.orig_iso)
