@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2015  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -30,7 +30,7 @@ import oz.OzException
 
 class UbuntuGuest(oz.Linux.LinuxCDGuest):
     """
-    Class for Ubuntu 5.04, 5.10, 6.06, 6.10, 7.04, 7.10, 8.04, 8.10, 9.04, 9.10, 10.04, 10.10, 11.04, 11.10, 12.04, 12.10, 13.04, 13.10, 14.04, 14.10, and 15.04 installation.
+    Class for Ubuntu 5.04, 5.10, 6.06, 6.10, 7.04, 7.10, 8.04, 8.10, 9.04, 9.10, 10.04, 10.10, 11.04, 11.10, 12.04, 12.10, 13.04, 13.10, 14.04, 14.10, 15.04, and 15.10 installation.
     """
     def __init__(self, tdl, config, auto, output_disk, initrd, nicmodel,
                  diskbus, macaddress):
@@ -172,7 +172,7 @@ PROMPT 0
                     kernelname = "/casper/vmlinuz"
                     if self.tdl.update in ["12.04.2", "12.04.3", "12.04.4",
                                            "12.04.5", "13.04", "13.10", "14.04",
-                                           "14.04.1", "14.10", "15.04"] and self.tdl.arch == "x86_64":
+                                           "14.04.1", "14.10", "15.04", "15.10"] and self.tdl.arch == "x86_64":
                         kernelname += ".efi"
                     f.write("  kernel " + kernelname + "\n")
                     f.write("  append file=/cdrom/preseed/customiso.seed boot=casper automatic-ubiquity noprompt keyboard-configuration/layoutcode=us initrd=/casper/" + self.casper_initrd + "\n")
@@ -706,7 +706,7 @@ def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
     if tdl.update in ["9.10", "10.04", "10.04.1", "10.04.2", "10.04.3", "10.10",
                       "11.04", "11.10", "12.04", "12.04.1", "12.04.2",
                       "12.04.3", "12.04.4", "12.04.5", "12.10", "13.04",
-                      "13.10", "14.04", "14.04.1", "14.10", "15.04"]:
+                      "13.10", "14.04", "14.04.1", "14.10", "15.04", "15.10"]:
         if netdev is None:
             netdev = 'virtio'
         if diskbus is None:
@@ -718,4 +718,4 @@ def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "Ubuntu: 5.04, 5.10, 6.06[.1,.2], 6.10, 7.04, 7.10, 8.04[.1,.2,.3,.4], 8.10, 9.04, 9.10, 10.04[.1,.2,.3], 10.10, 11.04, 11.10, 12.04[.1,.2,.3,.4,.5], 12.10, 13.04, 13.10, 14.04[.1], 14.10, 15.04"
+    return "Ubuntu: 5.04, 5.10, 6.06[.1,.2], 6.10, 7.04, 7.10, 8.04[.1,.2,.3,.4], 8.10, 9.04, 9.10, 10.04[.1,.2,.3], 10.10, 11.04, 11.10, 12.04[.1,.2,.3,.4,.5], 12.10, 13.04, 13.10, 14.04[.1], 14.10, 15.04, 15.10"
